@@ -30,9 +30,11 @@
 #include "canvas.h"
 #include "dnd.h"
 
-#define CARDNAME_FONT "-adobe-helvetica-medium-r-normal-*-*-180-*-*-p-*-iso8859-1"
-#define CANVAS_FONT "-adobe-helvetica-medium-r-*-*-*-120-*-*-p-*-iso8859-1"
-#define ADDR_FONT "-adobe-helvetica-medium-r-*-*-*-100-*-*-p-*-iso8859-1"
+#define CARDNAME_FONTSET "-adobe-helvetica-medium-r-normal-*-18-*-*-*-p-*-*-*,-cronyx-helvetica-medium-r-normal-*-20-*-*-*-p-*-koi8-r,-*-*-medium-r-normal-*-18-*-*-*-*-*-ksc5601.1987-0,*"
+#define TITLE_FONTSET "-adobe-helvetica-medium-r-*-*-14-*-*-*-p-*-*-*,-cronyx-helvetica-medium-r-normal-*-17-*-*-*-p-*-koi8-r,-*-*-medium-r-no-*-*-14-*-*-*-*-*-ksc5601.1987-0,*"
+#define COMMENT_FONTSET "-adobe-helvetica-medium-r-*-*-10-*-*-*-p-*-*-*,-cronyx-helvetica-medium-r-normal-*-11-*-*-*-p-*-koi8-r,-*-*-medium-r-*-*-10-*-*-*-*-*-ksc5601.1987-0,*"
+#define CANVAS_FONTSET "-adobe-helvetica-medium-r-*-*-12-*-*-*-p-*-*-*,-cronyx-helvetica-medium-r-normal-*-14-*-*-*-p-*-koi8-r,-*-*-medium-r-*-*-12-*-*-*-*-*-ksc5601.1987-0,*"
+#define ADDR_FONTSET "-adobe-helvetica-medium-r-*-*-10-*-*-*-p-*-*-*,-cronyx-helvetica-medium-r-normal-*-11-*-*-*-p-*-koi8-r,-*-*-medium-r-*-*-10-*-*-*-*-*-ksc5601.1987-0,*"
 #define CANVAS_WIDTH 225
 #define CANVAS_HEIGHT 350
 #define LIST_SPACING 15.0
@@ -70,6 +72,7 @@ gnomecard_canvas_new(void)
 	GtkStyle *style;
 	GnomeCanvasItem *item;
 	gint i;
+        GdkFont *cardname_font, *title_font, *canvas_font, *addr_font, *comment_font; 
 
 	canvas = gnomecard_canvas = gnome_canvas_new();
 	configure_source_card_dnd (canvas);
@@ -87,6 +90,12 @@ gnomecard_canvas_new(void)
 
 	root = GNOME_CANVAS_GROUP (gnome_canvas_root(GNOME_CANVAS(canvas)));
 
+        cardname_font = gdk_fontset_load (CARDNAME_FONTSET);
+	title_font = gdk_fontset_load (TITLE_FONTSET);
+	canvas_font = gdk_fontset_load (CANVAS_FONTSET);
+	addr_font = gdk_fontset_load (ADDR_FONTSET);
+	comment_font = gdk_fontset_load (COMMENT_FONTSET);
+
 	/* label at top of canvas, contains current cardname */
 	cardname_box = gnome_canvas_item_new (root, gnome_canvas_rect_get_type (),
 			       "x1", 5.0,
@@ -102,7 +111,7 @@ gnomecard_canvas_new(void)
 				      "text", "",
 				      "x", 6.0, /*CANVAS_WIDTH / 2.0,*/
 				      "y", 20.0,
-				      "font", CARDNAME_FONT,
+				      "fontset", CARDNAME_FONTSET,
 				      "anchor", GTK_ANCHOR_WEST,
 				      "fill_color", HEADER_TEXT_COLOR,
 				      NULL);
@@ -113,7 +122,7 @@ gnomecard_canvas_new(void)
 				      "text", "",
 				      "x", 5.0,
 				      "y", ypos,
-				      "font", CANVAS_FONT,
+				      "fontset", CANVAS_FONTSET,
 				      "anchor", GTK_ANCHOR_WEST,
 				      "fill_color", BODY_TEXT_COLOR,
 				      NULL);
@@ -124,7 +133,7 @@ gnomecard_canvas_new(void)
 				      "text", "",
 				      "x", 5.0,
 				      "y", ypos,
-				      "font", CANVAS_FONT,
+				      "fontset", CANVAS_FONTSET,
 				      "anchor", GTK_ANCHOR_WEST,
 				      "fill_color", BODY_TEXT_COLOR,
 				      NULL);
@@ -134,7 +143,7 @@ gnomecard_canvas_new(void)
 				      "text", "",
 				      "x", 5.0,
 				      "y", ypos,
-				      "font", CANVAS_FONT,
+				      "fontset", CANVAS_FONTSET,
 				      "anchor", GTK_ANCHOR_WEST,
 				      "fill_color", BODY_TEXT_COLOR,
 				      NULL);
@@ -145,7 +154,7 @@ gnomecard_canvas_new(void)
 				      "text", "",
 				      "x", 5.0,
 				      "y", ypos,
-				      "font", CANVAS_FONT,
+				      "fontset", CANVAS_FONTSET,
 				      "anchor", GTK_ANCHOR_WEST,
 				      "fill_color", BODY_TEXT_COLOR,
 				      NULL);
@@ -154,7 +163,7 @@ gnomecard_canvas_new(void)
 				      "text", "",
 				      "x", 5.0,
 				      "y", ypos,
-				      "font", CANVAS_FONT,
+				      "fontset", CANVAS_FONTSET,
 				      "anchor", GTK_ANCHOR_WEST,
 				      "fill_color", BODY_TEXT_COLOR,
 				      NULL);
@@ -172,10 +181,10 @@ gnomecard_canvas_new(void)
 			       NULL);
 
 	gnome_canvas_item_new (root, gnome_canvas_text_get_type (),
-				      "text", "Phone Numbers",
+				      "text", _("Phone Numbers"),
 				      "x", 10.0,
 				      "y", ypos+10,
-				      "font",  "-adobe-helvetica-medium-r-*-*-14-140-*-*-p-*-iso8859-1",
+				      "fontset",  TITLE_FONTSET,
 				      "anchor", GTK_ANCHOR_WEST,
 				      "fill_color", HEADER_TEXT_COLOR,
 				      NULL);
@@ -184,26 +193,26 @@ gnomecard_canvas_new(void)
 	gnome_canvas_item_new (root, gnome_canvas_rect_get_type (),
 			       "x1", 5.0,
 			       "y1", ypos-6.0,
-			       "x2", (double) 45.0,
+			       "x2", (double) 55.0,
 			       "y2", (double) ypos+6,
 			       "fill_color", LABEL_BOX_COLOR,
 			       "outline_color", LABEL_BOX_COLOR,
 			       "width_pixels", 0,
 			       NULL);
 	gnome_canvas_item_new (root, gnome_canvas_text_get_type (),
-				      "text", "Home:",
-				      "x", 40.0,
+				      "text", _("Home:"),
+				      "x", 50.0,
 				      "y", ypos,
-				      "font",  CANVAS_FONT,
+				      "fontset",  COMMENT_FONTSET,
 				      "anchor", GTK_ANCHOR_EAST,
 				      "fill_color", LABEL_TEXT_COLOR,
 				      NULL);
 
 	homephone = gnome_canvas_item_new (root, gnome_canvas_text_get_type (),
 				      "text", "",
-				      "x", 50.0,
+				      "x", 60.0,
 				      "y", ypos,
-				      "font", CANVAS_FONT,
+				      "fontset", CANVAS_FONTSET,
 				      "anchor", GTK_ANCHOR_WEST,
 				      "fill_color", BODY_TEXT_COLOR,
 				      NULL);
@@ -213,26 +222,26 @@ gnomecard_canvas_new(void)
 	gnome_canvas_item_new (root, gnome_canvas_rect_get_type (),
 			       "x1", 5.0,
 			       "y1", ypos-6.0,
-			       "x2", (double) 45.0,
+			       "x2", (double) 55.0,
 			       "y2", (double) ypos+6,
 			       "fill_color", LABEL_BOX_COLOR,
 			       "outline_color", LABEL_BOX_COLOR,
 			       "width_pixels", 0,
 			       NULL);
 	gnome_canvas_item_new (root, gnome_canvas_text_get_type (),
-				      "text", "Work:",
-				      "x", 40.0,
+				      "text", _("Work:"),
+				      "x", 50.0,
 				      "y", ypos,
-				      "font",  CANVAS_FONT,
+				      "fontset",  COMMENT_FONTSET,
 				      "anchor", GTK_ANCHOR_EAST,
 				      "fill_color", LABEL_TEXT_COLOR,
 				      NULL);
 
 	workphone = gnome_canvas_item_new (root, gnome_canvas_text_get_type (),
 				      "text", "",
-				      "x", 50.0,
+				      "x", 60.0,
 				      "y", ypos,
-				      "font", CANVAS_FONT,
+				      "fontset", CANVAS_FONTSET,
 				      "anchor", GTK_ANCHOR_WEST,
 				      "fill_color", BODY_TEXT_COLOR,
 				      NULL);
@@ -250,10 +259,10 @@ gnomecard_canvas_new(void)
 			       NULL);
 
 	gnome_canvas_item_new (root, gnome_canvas_text_get_type (),
-				      "text", "Addresses",
+				      "text", _("Addresses"),
 				      "x", 10.0,
 				      "y", ypos+10,
-				      "font",  "-adobe-helvetica-medium-r-*-*-14-140-*-*-p-*-iso8859-1",
+				      "fontset",  TITLE_FONTSET,
 				      "anchor", GTK_ANCHOR_WEST,
 				      "fill_color", HEADER_TEXT_COLOR,
 				      NULL);
@@ -271,10 +280,10 @@ gnomecard_canvas_new(void)
 			       NULL);
 
 	gnome_canvas_item_new (root, gnome_canvas_text_get_type (),
-				      "text", "Home",
+				      "text", _("Home"),
 				      "x", 15.0,
 				      "y", ypos+5,
-				      "font",  "-adobe-helvetica-medium-r-*-*-10-100-*-*-p-*-iso8859-1",
+				      "fontset",  COMMENT_FONTSET,
 				      "anchor", GTK_ANCHOR_WEST,
 				      "fill_color", LABEL_TEXT_COLOR,
 				      NULL);
@@ -285,7 +294,7 @@ gnomecard_canvas_new(void)
 						  "text", "",
 						  "x", 10.0,
 						  "y", ypos,
-						  "font", ADDR_FONT,
+						  "fontset", ADDR_FONTSET,
 						  "anchor", GTK_ANCHOR_WEST,
 						  "fill_color",BODY_TEXT_COLOR,
 						  NULL);
@@ -296,7 +305,7 @@ gnomecard_canvas_new(void)
 						  "text", "",
 						  "x", 10.0,
 						  "y", ypos,
-						  "font", ADDR_FONT,
+						  "fontset", ADDR_FONTSET,
 						  "anchor", GTK_ANCHOR_WEST,
 						  "fill_color",BODY_TEXT_COLOR,
 						  NULL);
@@ -307,7 +316,7 @@ gnomecard_canvas_new(void)
 						  "text", "",
 						  "x", 10.0,
 						  "y", ypos,
-						  "font", ADDR_FONT,
+						  "fontset", ADDR_FONTSET,
 						  "anchor", GTK_ANCHOR_WEST,
 						  "fill_color",BODY_TEXT_COLOR,
 						  NULL);
@@ -318,7 +327,7 @@ gnomecard_canvas_new(void)
 						  "text", "",
 						  "x", 10.0,
 						  "y", ypos,
-						  "font", ADDR_FONT,
+						  "fontset", ADDR_FONTSET,
 						  "anchor", GTK_ANCHOR_WEST,
 						  "fill_color",BODY_TEXT_COLOR,
 						  NULL);
@@ -338,10 +347,10 @@ gnomecard_canvas_new(void)
 			       NULL);
 
 	gnome_canvas_item_new (root, gnome_canvas_text_get_type (),
-				      "text", "Work",
+				      "text", _("Work"),
 				      "x", 15.0,
 				      "y", ypos+5,
-				      "font",  "-adobe-helvetica-medium-r-*-*-10-100-*-*-p-*-iso8859-1",
+				      "fontset", COMMENT_FONTSET,
 				      "anchor", GTK_ANCHOR_WEST,
 				      "fill_color", LABEL_TEXT_COLOR,
 				      NULL);
@@ -352,7 +361,7 @@ gnomecard_canvas_new(void)
 						  "text", "",
 						  "x", 10.0,
 						  "y", ypos,
-						  "font", ADDR_FONT,
+						  "fontset", ADDR_FONTSET,
 						  "anchor", GTK_ANCHOR_WEST,
 						  "fill_color",BODY_TEXT_COLOR,
 						  NULL);
@@ -363,7 +372,7 @@ gnomecard_canvas_new(void)
 						  "text", "",
 						  "x", 10.0,
 						  "y", ypos,
-						  "font", ADDR_FONT,
+						  "fontset", ADDR_FONTSET,
 						  "anchor", GTK_ANCHOR_WEST,
 						  "fill_color",BODY_TEXT_COLOR,
 						  NULL);
@@ -374,7 +383,7 @@ gnomecard_canvas_new(void)
 						  "text", "",
 						  "x", 10.0,
 						  "y", ypos,
-						  "font", ADDR_FONT,
+						  "fontset", ADDR_FONTSET,
 						  "anchor", GTK_ANCHOR_WEST,
 						  "fill_color",BODY_TEXT_COLOR,
 						  NULL);
@@ -385,7 +394,7 @@ gnomecard_canvas_new(void)
 						  "text", "",
 						  "x", 10.0,
 						  "y", ypos,
-						  "font", ADDR_FONT,
+						  "fontset", ADDR_FONTSET,
 						  "anchor", GTK_ANCHOR_WEST,
 						  "fill_color",BODY_TEXT_COLOR,
 						  NULL);
@@ -404,10 +413,10 @@ gnomecard_canvas_new(void)
 			       NULL);
 
 	gnome_canvas_item_new (root, gnome_canvas_text_get_type (),
-				      "text", "Memo(s)",
+				      "text", _("Memo(s)"),
 				      "x", 10.0,
 				      "y", ypos+10,
-				      "font",  "-adobe-helvetica-medium-r-*-*-14-140-*-*-p-*-iso8859-1",
+				      "fontset",  TITLE_FONTSET,
 				      "anchor", GTK_ANCHOR_WEST,
 				      "fill_color", HEADER_TEXT_COLOR,
 				      NULL);
@@ -418,7 +427,7 @@ gnomecard_canvas_new(void)
 				      "text", "",
 				      "x", 5.0,
 				      "y", ypos,
-				      "font", CANVAS_FONT,
+				      "fontset", CANVAS_FONTSET,
 				      "anchor", GTK_ANCHOR_WEST,
 				      "fill_color", BODY_TEXT_COLOR,
 				      NULL);
@@ -486,7 +495,12 @@ gnomecard_update_canvas(Card *crd)
 		
 		str = (crd->fname.str)? crd->fname.str : _("No fname for this card.");
 		
-		font = gdk_font_load(CARDNAME_FONT);
+		font = gdk_fontset_load(CARDNAME_FONTSET);
+		if (!font) {
+			font = gdk_font_load ("fixed");
+			g_assert (font != NULL);
+		}
+
 		width = gdk_string_width(font, str);
 		gdk_font_unref(font);
 		
