@@ -507,7 +507,6 @@ get_CardPostAddr(VObject *o)
 	VObject *vo;
 	char *the_str;
 	CardPostAddr *addr;
-	int i;
 	
 	addr = malloc(sizeof(CardPostAddr));
 
@@ -1285,18 +1284,20 @@ card_convert_to_vobject(Card *crd)
 		for (node = crd->postal.l; node; node = node->next) {
 			CardPostAddr *postaddr = (CardPostAddr *) node->data;
 			
-			vprop = addProp(vobj, VCAdrProp);
-			add_AddrType(vprop, postaddr->type);
+			if (postaddr->prop.used) {
+				vprop = addProp(vobj, VCAdrProp);
+				add_AddrType(vprop, postaddr->type);
 /* NOT IMPLEMENTED
-			add_strProp(vprop, VCPostalBoxProp, postaddr->data[PO]);
+			        add_strProp(vprop, VCPostalBoxProp, postaddr->data[PO]);
 */
-			add_strProp(vprop, VCExtAddressProp,postaddr->street2);
-			add_strProp(vprop, VCStreetAddressProp,postaddr->street1);
-			add_strProp(vprop, VCCityProp, postaddr->city);
-			add_strProp(vprop, VCRegionProp, postaddr->state);
-			add_strProp(vprop, VCPostalCodeProp, postaddr->zip);
-			add_strProp(vprop, VCCountryNameProp, postaddr->country);
-			add_CardProperty(vprop, &postaddr->prop);
+				add_strProp(vprop, VCExtAddressProp,postaddr->street2);
+				add_strProp(vprop, VCStreetAddressProp,postaddr->street1);
+				add_strProp(vprop, VCCityProp, postaddr->city);
+				add_strProp(vprop, VCRegionProp, postaddr->state);
+				add_strProp(vprop, VCPostalCodeProp, postaddr->zip);
+				add_strProp(vprop, VCCountryNameProp, postaddr->country);
+				add_CardProperty(vprop, &postaddr->prop);
+			}
 		}
 	}
 /* NOT IMPLEMENTED
@@ -1319,10 +1320,12 @@ card_convert_to_vobject(Card *crd)
 		for (node = crd->phone.l; node; node = node->next) {
 			CardPhone *phone = (CardPhone *) node->data;
 			
-			vprop = add_strProp(vobj, VCTelephoneProp, 
-					    phone->data);
-			add_PhoneType(vprop, phone->type);
-			add_CardProperty(vprop, &phone->prop);
+			if (phone->prop.used) {
+				vprop = add_strProp(vobj, VCTelephoneProp, 
+						    phone->data);
+				add_PhoneType(vprop, phone->type);
+				add_CardProperty(vprop, &phone->prop);
+			}
 		}
 	}
 
@@ -1341,7 +1344,7 @@ card_convert_to_vobject(Card *crd)
 	}
 */
 /* Instead we have a single email field */
-	if (crd->email.prop.used) {
+	if (crd->email.prop.used && crd->email.address) {
 	    vprop = add_strProp(vobj, VCEmailAddressProp, crd->email.address);
 			add_EMailType(vprop, crd->email.type);
 			add_CardProperty(vprop, &crd->email.prop);
